<!DOCTYPE html>
<html>

<!-- Mirrored from html.yogsthemes.com/demo/banqix/service-detail.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:00:49 GMT -->
<head>
<meta charset="utf-8">
<title>Banqix TV & Internet Business HTML-5 Template | Services Detail</title>
<!-- Stylesheets -->
<link href="assets/css/bootstrap.css" rel="stylesheet">
<link href="assets/css/style.css" rel="stylesheet">
<link href="assets/css/meanmenu.min.css" rel="stylesheet">
<link href="assets/css/responsive.css" rel="stylesheet">

<!-- Color Switcher Mockup -->
<link href="assets/css/color-switcher-design.css" rel="stylesheet">

<!-- Color Themes -->
<link id="theme-color-file" href="assets/css/color-themes/default-color.css" rel="stylesheet">

<link href="https://fonts.googleapis.com/css2?family=Unbounded:wght@300;400;500;600;700;800;900&amp;display=swap" rel="stylesheet">
<link href="https://fonts.googleapis.com/css2?family=DM+Sans:opsz,wght@9..40,300;9..40,400;9..40,500;9..40,600;9..40,700;9..40,800;9..40,900&amp;display=swap" rel="stylesheet">

<link rel="shortcut icon" href="assets/images/favicon.png" type="image/x-icon">
<link rel="icon" href="assets/images/favicon.png" type="image/x-icon">

<!-- Responsive -->
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0">

<!--[if lt IE 9]><script src="https://cdnjs.cloudflare.com/ajax/libs/html5shiv/3.7.3/html5shiv.js"></script><![endif]-->
<!--[if lt IE 9]><script src="js/respond.js"></script><![endif]-->
</head>

<body>

<div class="page-wrapper">
	
	<!-- Cursor -->
	<div class="cursor"></div>
	<div class="cursor-follower"></div>
	<!-- Cursor End -->
 	
	<!-- Preloader -->
    <div class="preloader"></div>
	<!-- End Preloader -->
	
	<!-- Main Header / Header Style Four -->
	<header class="main-header header-style-four">
		
		<!-- Header Upper -->
		<div class="header-upper" style="background-image:url(assets/images/background/4.jpg)">
			<div class="auto-container">
				<div class="d-flex justify-content-between align-items-center flex-wrap">
					<!-- Info List -->
					<ul class="header-top_list-two d-flex align-items-center flex-wrap">
						<li><span class="icon fa-solid fa-clock fa-fw"></span>Mon-Fri : 9am to 6pm</li>
						<li><span class="icon fa-solid fa-envelope fa-fw"></span>needhelp@company.com</li>
					</ul>

					<!-- Logo -->
					<div class="logo"><a href="index.html"><img src="assets/images/logo.png" alt="" title=""></a></div>

					<div class="right-box d-flex align-items-center flex-wrap">

						<!-- Language DropDown -->
						<div class="language-dropdown">
							<button class="btn dropdown-toggle" type="button" id="dropdownMenuButton1" data-bs-toggle="dropdown" aria-expanded="false">
								<span class="flag"><img src="assets/images/icons/flag.png" alt="" /></span> English &nbsp;<span class="fa-solid fa-angle-down fa-fw"></span>
							  </button>
							<ul class="dropdown-menu" aria-labelledby="dropdownMenuButton1">
								<li><a class="dropdown-item" href="#">English</a></li>
								<li><a class="dropdown-item" href="#">Arbic</a></li>
								<li><a class="dropdown-item" href="#">German</a></li>
								<li><a class="dropdown-item" href="#">French</a></li>
							</ul>
						</div>

						<!-- Header Search Box -->
						<div class="header-search_box">
							<form method="post" action="https://html.yogsthemes.com/demo/banqix/contact.html">
								<div class="form-group">
									<input type="search" name="search-field" value="" placeholder="I’m Looking for..." required>
									<button type="submit"><span class="icon fa fa-search"></span></button>
								</div>
							</form>
						</div>

					</div>

				</div>
			</div>
		</div>

		<!-- Header Upper -->
		<div class="header-lower">
			<div class="auto-container">
				<div class="inner-container">
					<div class="d-flex justify-content-between align-items-center flex-wrap">
						
						<!-- Header Two Socials -->
						<div class="header-two_socials">
							<a class="fa-brands fa-facebook-f fa-fw" href="#"></a>
							<a class="fa-brands fa-instagram fa-fw" href="#"></a>
							<a class="fa-brands fa-twitter fa-fw" href="#"></a>
							<a class="fa-brands fa-youtube fa-fw" href="#"></a>
						</div>
						
						<div class="nav-outer d-flex flex-wrap">
							<!-- Main Menu -->
							<nav class="main-menu navbar-expand-md">
								<div class="navbar-header">
									<!-- Toggle Button -->    	
									<button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
										<span class="icon-bar"></span>
										<span class="icon-bar"></span>
										<span class="icon-bar"></span>
									</button>
								</div>
								
								<div class="navbar-collapse collapse clearfix" id="navbarSupportedContent">
									<ul class="navigation clearfix">
										<li class="dropdown"><a href="#">Home</a>
											<ul>
												<li><a href="index.html">Homepage 01</a></li>
												<li><a href="index-2.html">Homepage 02</a></li>
												<li><a href="index-3.html">Homepage 03</a></li>
												<li><a href="index-4.html">Homepage 04</a></li>
												<li class="dropdown"><a href="#">Header Styles</a>
													<ul>
														<li><a href="index.html">Header 01</a></li>
														<li><a href="index-2.html">Header 02</a></li>
														<li><a href="index-3.html">Header 03</a></li>
														<li><a href="index-4.html">Header 04</a></li>
													</ul>
												</li>
											</ul>
										</li>
										<li class="dropdown"><a href="#">About</a>
											<ul>
												<li><a href="about.html">About us</a></li>
												<li><a href="faq.html">Faq</a></li>
												<li><a href="price.html">price</a></li>
												<li><a href="privacy.html">Privacy Policy</a></li>
												<li><a href="terms.html">Terms & Condition</a></li>
												<li class="dropdown"><a href="#">Team</a>
													<ul>
														<li><a href="team.html">Team</a></li>
														<li><a href="team-detail.html">Team Detail</a></li>
													</ul>
												</li>
											</ul>
										</li>
										<li class="dropdown"><a href="#">service</a>
											<ul>
												<li><a href="services.html">Services</a></li>
												<li><a href="service-detail.html">service detail</a></li>
											</ul>
										</li>
										<li class="dropdown"><a href="#">shop</a>
											<ul>
												<li><a href="shop.html">shop</a></li>
												<li><a href="shop-detail.html">shop detail</a></li>
												<li><a href="coming-soon.html">coming soon</a></li>
											</ul>
										</li>
										<li class="dropdown"><a href="#">Blog</a>
											<ul>
												<li><a href="blog.html">Our Blog</a></li>
												<li><a href="blog-detail.html">Blog Detail</a></li>
												<li><a href="not-found.html">Not Found</a></li>
											</ul>
										</li>
										<li><a href="contact.html">Contact</a></li>
									</ul>
								</div>
							</nav>
						</div>

						<!-- Main Menu End-->
						<div class="outer-box d-flex align-items-center flex-wrap">
							
							<!-- Login Box -->
							<a class="header-login_box" href="#">
								<i class="fa-regular fa-user fa-fw"></i>
							</a>

							<!-- Nav Btn -->
							<div class="nav-btn navSidebar-button">
								<i class="fas fa-shopping-cart fa-fw"></i>
								<span>2</span>
							</div>

							<!-- About Widget -->
							<span class="about-widget">
								<img src="assets/images/icons/grid-icon.png" alt="" />
							</span>

							<!-- Mobile Navigation Toggler -->
							<div class="mobile-nav-toggler"><span class="icon flaticon-menu"></span></div>
						</div>
						
					</div>
				</div>
			</div>
		</div>
		<!--End Header Upper-->
		
		<!-- Mobile Menu  -->
		<div class="mobile-menu">
			<div class="menu-backdrop"></div>
			<div class="close-btn"><span class="icon flaticon-multiply"></span></div>
			
			<nav class="menu-box">
				<div class="nav-logo"><a href="index.html"><img src="assets/images/logo.png" alt="" title=""></a></div>
				<div class="menu-outer"><!--Here Menu Will Come Automatically Via Javascript / Same Menu as in Header--></div>
			</nav>
		</div>
		<!-- End Mobile Menu -->
	
	</header>
	<!-- End Main Header / Header Four -->
	
	<!-- Sidebar Cart Item -->
	<div class="xs-sidebar-group info-group">
		<div class="xs-overlay xs-bg-black"></div>
		<div class="xs-sidebar-widget">
			<div class="sidebar-widget-container">
				<div class="close-button">
					<span class="fa-solid fa-xmark fa-fw"></span>
				</div>
				<div class="sidebar-textwidget">
					
					<!-- Sidebar Info Content -->
					<div class="sidebar-info-contents">
						<div class="content-inner">
						
							<!-- Title Box -->
							<div class="title-box">
								<h5>Broadband <span>connection</span></h5>
								<div class="price">$15 from free economy shipping</div>
							</div>
							
							<!-- Empty Cart Box -->
							<div class="empty-cart-box">
								<!-- No Product -->
								<div class="no-cart">
									<span class="icon fa-solid fa-cart-flatbed-suitcase fa-fw"></span>
									No products in cart.
								</div>
							</div>
							
							<!-- Lower Box -->
							<div class="lower-box">
								<h5>Popular <span>Suggestions</span></h5>
									
								<!-- Post Block -->
								<div class="post-block">
									<div class="inner-box">
										<div class="image">
											<img src="assets/images/resource/post-thumb-1.jpg" alt="" />
										</div>
										<h6><a href="#">Free Installation</a></h6>
										<div class="rating">
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
										</div>
										<div class="price-box">$125</div>
										<a class="theme-btn bag-btn" href="#">add to bag</a>
									</div>
								</div>
								
								<!-- Post Block -->
								<div class="post-block">
									<div class="inner-box">
										<div class="image">
											<img src="assets/images/resource/post-thumb-2.jpg" alt="" />
										</div>
										<h6><a href="#">Ultra Fast Connect</a></h6>
										<div class="rating">
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
										</div>
										<div class="price-box">$205</div>
										<a class="theme-btn bag-btn" href="#">add to bag</a>
									</div>
								</div>
								
								<!-- Post Block -->
								<div class="post-block">
									<div class="inner-box">
										<div class="image">
											<img src="assets/images/resource/post-thumb-3.jpg" alt="" />
										</div>
										<h6><a href="#">4K and 8K Quality</a></h6>
										<div class="rating">
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
										</div>
										<div class="price-box">$25</div>
										<a class="theme-btn bag-btn" href="#">add to bag</a>
									</div>
								</div>
								
							</div>
							
						</div>
					</div>
					
				</div>
			</div>
		</div>
	</div>
	<!-- End Sidebar Cart Item -->

	<!-- About Sidebar -->
	<div class="about-sidebar">
		<div class="gradient-layer"></div>
		<!-- Close Button -->
		<div class="close-sidebar-widget close-button">
			<span class="fa-solid fa-xmark fa-fw"></span>
		</div>
		<div class="sidebar-inner">
			<div class="upper-box">
				<div class="image">
					<img src="assets/images/resource/about-1.jpg" alt="" />
				</div>
				<div class="content-box">
					<h3>About <span>Monic</span></h3>
					<div class="text">Many desktop Wifi packages & web page editors now use Ipsum budgets dipiscing</div>
					<ul class="about-one_list">
						<li>Internet with 50 Mbps</li>
						<li>Night Turbo-Speed</li>
						<li>WiFi router & prevention</li>
						<li>Unlimited devices</li>
					</ul>
				</div>
			</div>
			<!-- Social Box -->
			<div class="social-box">
				<a href="https://facebook.com/"><i class="fa-brands fa-facebook-f"></i></a>
				<a href="https://twitter.com/"><i class="fa-brands fa-twitter"></i></a>
				<a href="https://youtube.com/"><i class="fa-brands fa-youtube"></i></a>
				<a href="https://instagram.com/"><i class="fa-brands fa-instagram"></i></a>
			</div>
		</div>
	</div>
	<!-- End About Sidebar -->

	<!-- Page Title Two -->
    <section class="page-title_two" style="background-image:url(assets/images/background/1.jpg)">
		<div class="page-title_two-gradient"></div>
        <div class="auto-container_two">
			<h2>Services Detail</h2>
			<ul class="breadcrumb clearfix">
				<li><a href="index.html">Home</a></li>
				<li>Services Detail</li>
			</ul>
        </div>
    </section>
    <!-- End Page Title Two -->

	<!-- Sidebar Page Container -->
    <div class="sidebar-page-container left-sidebar">
    	<div class="auto-container_two">
        	<div class="row clearfix">
				
				<!-- Sidebar Side -->
                <div class="sidebar-side col-lg-4 col-md-12 col-sm-12">
                	<aside class="sidebar">

						<!-- Sidebar Widget -->
						<div class="sidebar-widget search-box">
							<div class="widget-content">
								<form method="post" action="https://html.yogsthemes.com/demo/banqix/contact.html">
									<div class="form-group">
										<input type="search" name="search-field" value="" placeholder="Search..." required>
										<button type="submit"><span class="icon fa fa-search"></span></button>
									</div>
								</form>
							</div>
						</div>

						<!-- Category Widget -->
						<div class="sidebar-widget category-widget">
							<h4 class="sidebar-title">Category</h4>
							<div class="widget-content">
								<ul class="category-list">
									<li><a href="#">Wi fi Internet</a></li>
									<li><a href="#">Broadband Line</a></li>
									<li><a href="#">Netfix TV Box</a></li>
									<li><a href="#">Cyber Security</a></li>
									<li><a href="#">Smart Television</a></li>
								</ul>
							</div>
						</div>

						<!-- Help Widget -->
						<div class="sidebar-widget help-widget" style="background-image:url(assets/images/resource/help-widget.jpg)">
							<h3>Have You any Question ?</h3>
							<div class="help-widget_icon">
								<i class="fa-solid fa-phone fa-fw"></i>
							</div>
							<div class="help-widget_text">Call Any Time</div>
							<a class="help-widget_phone" href="tel:+92-307-68-06860">+ 92 (307) 68 - 06860</a>
						</div>

					</aside>
				</div>

				<!-- Content Side -->
                <div class="content-side col-lg-8 col-md-12 col-sm-12">
                	<div class="service-detail">
						<div class="service-detail_inner">
							<div class="service-detail_image">
								<img src="assets/images/resource/service-13.jpg" alt="" />
							</div>
							<div class="service-detail_content">
								<h3 class="service-detail_heading">Fiber & Broadband Line</h3>
								<p>Broadband internet services refer to high-speed internet access that is faster and more efficient than traditional dial-up internet. Broadband connections provide a continuous, always-on connection to the internet, allowing users to access online contend.</p>
								<p>Ongoing advancements, such as the deployment of 5G networks and the expansion of fiber-optic infrastructure, aim to improve the speed and reliability of broadband services.</p>
								<ul class="service-detail_list">
									<li>In some areas, particularly rural or remote locations, access to broadband services may be limited.</li>
									<li>Broadband services can vary in cost, and factors such as speed and data limits may affect pricing.</li>
									<li>Some broadband plans may have data usage limits, restricting the amount of data a user..</li>
									<li>Broadband facilitates remote work through conferencing, file sharing, & other collaborative tools.</li>
								</ul>
								<p>Ongoing advancements, such as the deployment of 5G networks and the expansion of fiber-optic infrastructure, contribute to even faster and more reliable broadband services.</p>
								<div class="service-detail_image-two">
									<img src="assets/images/resource/service-14.jpg" alt="" />
									<a href="https://www.youtube.com/watch?v=YS3PwmOQ1Fc" class="lightbox-video service-detail_play"><span class="fa-solid fa-circle-pause fa-fw"><i class="ripple"></i></span></a>
								</div>
								<p>Broadband providers often differentiate their services based on factors like speed, reliability, and customer support. Quality of Service agreements may prioritize certain types of traffic (e.g., video streaming, gaming) to ensure a better user experience.</p>
								<!-- About Three Tabs -->
								<div class="service-detail_tabs">
									<!-- Serices Tabs -->
									<div class="service-detail_tab tabs-box">
									
										<!-- Tab Btns -->
										<ul class="tab-btns tab-buttons clearfix">
											<li data-tab="#prod-specializations" class="tab-btn active-btn">Specializations</li>
											<li data-tab="#prod-intelligence" class="tab-btn">Intelligence</li>
											<li data-tab="#prod-support" class="tab-btn">Super Support</li>
										</ul>
										
										<!-- Tabs Container -->
										<div class="tabs-content">
											
											<!-- Tab -->
											<div class="tab active-tab" id="prod-specializations">
												<div class="content">
													<div class="text">Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nullapariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa quisit ,officia deserunt mollit anim id est laborum. Sed ut perspiciatis unde omnis is amet natus error sit voluptatem accusantium doloremque laudantium, totam reaperiam, eaque ipsa quae ab ilnventor veritatis et quasi architecto beatae vitae dicta sunt explicabo. Nemo enim ipsavoluptate quia voluptas sit aspernatur aut odit aufugit.</div>
												</div>
											</div>

											<!-- Tab -->
											<div class="tab" id="prod-intelligence">
												<div class="content">
													<div class="text">Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nullapariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa quisit ,officia deserunt mollit anim id est laborum. Sed ut perspiciatis unde omnis is amet natus error sit voluptatem accusantium doloremque laudantium, totam reaperiam, eaque ipsa quae ab ilnventor veritatis et quasi architecto beatae vitae dicta sunt explicabo. Nemo enim ipsavoluptate quia voluptas sit aspernatur aut odit aufugit.</div>
												</div>
											</div>

											<!-- Tab -->
											<div class="tab" id="prod-support">
												<div class="content">
													<div class="text">Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nullapariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa quisit ,officia deserunt mollit anim id est laborum. Sed ut perspiciatis unde omnis is amet natus error sit voluptatem accusantium doloremque laudantium, totam reaperiam, eaque ipsa quae ab ilnventor veritatis et quasi architecto beatae vitae dicta sunt explicabo. Nemo enim ipsavoluptate quia voluptas sit aspernatur aut odit aufugit.</div>
												</div>
											</div>

										</div>
									</div>
								</div>
								<div class="middle-box">
									<div class="row clearfix">
										<!-- Column -->
										<div class="column col-lg-5 col-md-5 col-sm-12">
											<div class="service-detail_image-three">
												<img src="assets/images/resource/service-15.jpg" alt="" />
											</div>
										</div>
										<!-- Column -->
										<div class="column col-lg-7 col-md-7 col-sm-12">
											<h4 class="service-detail_subheading">Services of Benefits</h4>
											<p>High-speed broadband services can be relatively expensive, depending on the region and the chosen plan.</p>
											<ul class="service-detail_list-two">
												<li><i class="fa-solid fa-check fa-fw"></i>Duis aute irure dolor in reprehenderit in voluptate</li>
												<li><i class="fa-solid fa-check fa-fw"></i>Voluptate velit esse cillum dolore eu fugiat nulla pariatu.</li>
												<li><i class="fa-solid fa-check fa-fw"></i>Kuis nostr exercitation ullamco laboris consequat.</li>
											</ul>
										</div>
									</div>
								</div>
								<p>Ongoing advancements, such as the deployment of 5G networks and the expansion of fiber-optic infrastructure, contribute to even faster and more reliable broadband services. It's important to research and compare broadband providers in your area to find a service that meets your specific needs in terms of speed, reliability, and pricing.</p>
							</div>
						</div>
					</div>
				</div>

			</div>
		</div>
	</div>

	<!-- Footer Style Two -->
	<footer class="footer-style_two">
		<div class="footer-style_two-image alternate" style="background-image:url(assets/images/background/2.jpg)"></div>
		<div class="auto-container_two">
			<!-- Upper Box -->
			<div class="upper-box">
				<div class="row clearfix">
					
					<!-- Logo Column -->
					<div class="footer-two_logo-column col-lg-6 col-md-12 col-sm-12">
						<div class="logo"><a href="index.html"><img src="assets/images/logo-3.png" alt="" title=""></a></div>
						<!-- Social Box -->
						<div class="footer-two_socials">
							<a href="https://facebook.com/"><i class="fa-brands fa-facebook-f"></i></a>
							<a href="https://twitter.com/"><i class="fa-brands fa-twitter"></i></a>
							<a href="https://youtube.com/"><i class="fa-brands fa-youtube"></i></a>
							<a href="https://instagram.com/"><i class="fa-brands fa-instagram"></i></a>
						</div>
					</div>

					<!-- Subscribe Column -->
					<div class="footer-two_subscribe-column col-lg-6 col-md-12 col-sm-12">
						<div class="inner-column">
							<h4>Sign up to get latest <br> Updates</h4>
							<div class="text">Latest news, AI models & fun memes from the community.</div>
							<div class="subscribe-box">
								<form method="post" action="https://html.yogsthemes.com/demo/banqix/contact.html">
									<div class="form-group">
										<input type="email" name="search-field" value="" placeholder="Enter Your Email" required>
										<button type="submit" class="theme-btn btn-style-one">
											<span class="btn-wrap">
												<span class="text-one">Subscribe Now <i class="fa-solid fa-plus fa-fw"></i></span>
												<span class="text-two">Subscribe Now <i class="fa-solid fa-plus fa-fw"></i></span>
											</span>
										</button>
									</div>
								</form>
							</div>
						</div>
					</div>

				</div>
			</div>
			<!-- Widgets Section -->
			<div class="widgets-section">
				<div class="row clearfix">

					<!-- Footer Column -->
					<div class="footer_column col-lg-4 col-md-6 col-sm-12">
						<div class="footer-widget gallery-widget">
							<h4 class="footer-title">Service Schedule</h4>
							<ul class="timing-list">
								<li>Mon-Tues<span>03.00AM - 08.00PM</span></li>
								<li>Wedne-Thur<span>07.00AM - 09.00PM</span></li>
								<li>Fri-Sat<span>06.00AM - 11.00PM</span></li>
							</ul>
						</div>
					</div>

					<!-- Footer Column -->
					<div class="footer_column col-lg-4 col-md-6 col-sm-12">
						<div class="footer-widget lists-widget">
							<h4 class="footer-title">Get Free Link</h4>
							<ul class="footer-list_two">
								<li><a href="#">IT Consulting</a></li>
								<li><a href="#">Others</a></li>
								<li><a href="#">Data Analytics</a></li>
								<li><a href="#">UI & UX Design</a></li>
								<li><a href="#">Network Solutions</a></li>
								<li><a href="#">Software Development</a></li>
							</ul>
						</div>
					</div>

					<!-- Footer Column -->
					<div class="footer_column col-lg-4 col-md-6 col-sm-12">
						<div class="footer-widget instagram-widget">
							<h4 class="footer-title">Instagram</h4>
							<div class="images-outer clearfix">
								<!--Image Box-->
								<figure class="image-box"><a class="lightbox-image" href="assets/images/gallery/1.jpg"><img src="assets/images/gallery/instagram-1.jpg" alt=""></a></figure>
								<!--Image Box-->
								<figure class="image-box"><a class="lightbox-image" href="assets/images/gallery/2.jpg"><img src="assets/images/gallery/instagram-2.jpg" alt=""></a></figure>
								<!--Image Box-->
								<figure class="image-box"><a class="lightbox-image" href="assets/images/gallery/3.jpg"><img src="assets/images/gallery/instagram-3.jpg" alt=""></a></figure>
								<!--Image Box-->
								<figure class="image-box"><a class="lightbox-image" href="assets/images/gallery/1.jpg"><img src="assets/images/gallery/instagram-1.jpg" alt=""></a></figure>
								<!--Image Box-->
								<figure class="image-box"><a class="lightbox-image" href="assets/images/gallery/2.jpg"><img src="assets/images/gallery/instagram-2.jpg" alt=""></a></figure>
								<!--Image Box-->
								<figure class="image-box"><a class="lightbox-image" href="assets/images/gallery/3.jpg"><img src="assets/images/gallery/instagram-3.jpg" alt=""></a></figure>
							</div>
						</div>
					</div>

				</div>
			</div>

			<div class="footer-bottom">
				<div class="d-flex justify-content-between align-items-center flex-wrap">

					<ul class="footer-bottom_nav">
						<li><a href="#">Policy & Privacy</a></li>
						<li><a href="#">Terms & Condition</a></li>
					</ul>

					<!-- Copyright -->
					<div class="main-footer_copyright">Copyright &copy; 2023. All Rights Reserved.</div>

				</div>
			</div>

		</div>
	</footer>
	<!-- End Footer Style Two -->

	<!-- Search Popup -->
	<div class="search-popup">
		<div class="color-layer"></div>
		<button class="close-search"><span class="flaticon-close-1"></span></button>
		<form method="post" action="https://html.yogsthemes.com/demo/banqix/blog.html">
			<div class="form-group">
				<input type="search" name="search-field" value="" placeholder="Search Here" required="">
				<button class="fa fa-solid fa-magnifying-glass fa-fw" type="submit"></button>
			</div>
		</form>
	</div>
	<!-- End Search Popup -->
	
	<!-- Color Palate / Color Switcher -->
	<div class="color-palate">
		<div class="color-trigger">
			<i class="fa fa-solid fa-gear fa-fw"></i>
		</div>
		<div class="color-palate-inner">
			<div class="color-palate-head">
				<h6>Choose Options</h6>
			</div>
			
			<!-- Colors -->
			<div class="various-color clearfix">
				<div class="colors-list">
					<span class="palate default-color active" data-theme-file="assets/css/color-themes/default-color.css"></span>
					<span class="palate blue-color" data-theme-file="assets/css/color-themes/blue-color.css"></span>
					<span class="palate olive-color" data-theme-file="assets/css/color-themes/olive-color.css"></span>
					<span class="palate orange-color" data-theme-file="assets/css/color-themes/orange-color.css"></span>
					<span class="palate purple-color" data-theme-file="assets/css/color-themes/purple-color.css"></span>
					<span class="palate green-color" data-theme-file="assets/css/color-themes/green-color.css"></span>
					<span class="palate brown-color" data-theme-file="assets/css/color-themes/brown-color.css"></span>
					<span class="palate yellow-color" data-theme-file="assets/css/color-themes/yellow-color.css"></span>
				</div>
			</div>
					
			<h6>RTL Version</h6>
			<ul class="rtl-version option-box"> <li class="rtl">RTL Version</li> <li>LTR Version</li> </ul>
			<h6>Want Sticky Header</h6>
			<ul class="header-version option-box"> <li class="box">No</li> <li>Yes</li></ul>
			<h6>Dark Verion</h6>
			<ul class="dark-version option-box"> <li class="box">Yes</li> <li>No</li></ul>
			
			<div class="purchase-box">
				You will find much more options for colors and styling in admin panel. This color picker is used only for demonstation purposes.
				<a href="#" class="theme-btn btn-style-two">
					<span class="btn-wrap">
						<span class="text-one">buy now</span>
						<span class="text-two">buy now</span>
					</span>
				</a>
			</div>
			
		</div>
	</div>
	<!-- End Color Palate / Color Switcher -->
	
</div>
<!-- End PageWrapper -->

<div class="progress-wrap">
	<svg class="progress-circle svg-content" width="100%" height="100%" viewBox="-1 -1 102 102">
		<path d="M50,1 a49,49 0 0,1 0,98 a49,49 0 0,1 0,-98"/>
	</svg>
</div>

<script src="assets/js/jquery.js"></script>
<script src="assets/js/popper.min.js"></script>
<script src="assets/js/bootstrap.min.js"></script>
<script src="assets/js/appear.js"></script>
<script src="assets/js/parallax.min.js"></script>
<script src="assets/js/tilt.jquery.min.js"></script>
<script src="assets/js/jquery.paroller.min.js"></script>
<script src="assets/js/wow.js"></script>
<script src="assets/js/swiper.min.js"></script>
<script src="assets/js/backtotop.js"></script>
<script src="assets/js/odometer.js"></script>
<script src="assets/js/parallax-scroll.js"></script>

<script src="assets/js/gsap.min.js"></script>
<script src="assets/js/SplitText.min.js"></script>
<script src="assets/js/ScrollTrigger.min.js"></script>
<script src="assets/js/ScrollToPlugin.min.js"></script>
<script src="assets/js/ScrollSmoother.min.js"></script>

<script src="assets/js/magnific-popup.min.js"></script>
<script src="assets/js/jquery.meanmenu.min.js"></script>
<script src="assets/js/nav-tool.js"></script>
<script src="assets/js/jquery-ui.js"></script>
<script src="assets/js/element-in-view.js"></script>
<script src="assets/js/color-settings.js"></script>
<script src="assets/js/script.js"></script>

</body>

<!-- Mirrored from html.yogsthemes.com/demo/banqix/service-detail.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:00:52 GMT -->
</html>